param(
[Parameter(Mandatory=$True,
           helpmessage="Unique name to ensure data is counted only once and result can be identifed")]
           [string]$namespace,

[Parameter(Mandatory=$True,
           helpmessage="Enter directory where the output should be written to")]
           [string]$directory,
           
[Parameter(Mandatory=$True,
           helpmessage="Enter path to the history file")]
           [string]$historyfile                        
)

# Modification Date: 01/14/15


$productId   = "12"
$productName = "Tivoli Storage Manager FastBack Server"
$itemTtype   = "backup";

function parseUsageData()
{
   $enterJob = $False
   $size = 0
   $jobValue = -1
   $totalSize = 0
   $count = 0   
   $vId = 0
   
   $foundSize = $False
   $foundBaseJob = $False
   $foundVolumeId = $False
   
   $file = New-Object System.IO.StreamReader("$historyfile")
   while (($line = $file.ReadLine()) -ne $null)
   {                
      if ($enterJob)
      {         
         $tokens = $line.split("=")
         $key = $tokens[0].trim()        
         
         if ($key -eq "Size")
         {
            $size = $tokens[1].trim()
            $foundSize = $True
         }
         
         if ($key -eq "Base Job")
         {
            $jobValue = $tokens[1].trim()            
            $foundBaseJob = $True            
         }
         
         if ($key -eq "Volume ID")
         {
            $vId = $tokens[1].trim() 
            $foundVolumeId = $True                      
         }
         
         if ($foundSize -and $foundBaseJob -and $foundVolumeId)
         {            
            $enterJob = $False
            $foundSize = $False
            $foundBaseJob = $False
            if (($jobValue -eq 0) -and ($vId -ne 0))
            {              
               $count += 1               
               $totalSize += $size 
               $jobValue = -1
               $size = 0                            
            }           
         }         
      }
   
      if ($line -match "\[JOB.+\]")
      {
         if ($enterJob = $True)
         {
            $foundSize = $False
            $foundBaseJob = $False
            $foundVolumeId = $False
            $jobValue = -1
            $size = 0
         }               
         $enterJob = $True
      }  
   }
   $file.close()  
   
   $totalSize = [decimal]::round($totalSize/1024)
   Write-Host "`nQuery result:";
   Write-Host "Number of objects:" $count
   Write-Host "Size (MB):         $totalSize"
   createXmlFile $count $totalSize     
}

function createXmlFile($count, $size)
{ 
   $cmdStr = '.\dsmfecc "--create" "--namespace=$namespace" "--productid=$productId" "--directory=$directory" "--applicationentity=$namespace" "--numberofobjects=$count" "--size=$size" "--type=$itemTtype" 2>&1'
   
   Write-Host "`nCreate XML file"       
   Invoke-Expression $cmdStr
   if ($LastExitCode -ne 0)
   {
      Write-Host "Create XML file failed."      
      exit
   }    
}

Write-Host "`n"
Write-Host "********************************************************************"
Write-Host "******** Tivoli Storage Manager Suite for Unified Recovery *********"
Write-Host "********      Front-End Terabyte (TB) Capacity Report      *********"
Write-Host "********************************************************************`n"
Write-Host "$productName`n"

parseUsageData

